##  User Statuses
The following table lists the tabs that appear on the Users page, each corresponding to different user statuses.
Tab (User Status) | Description
---|---
All | All workspaces users, except for archived ones.
Active | Users whose permission for the workspace is active.
Invited | Invited users who haven't yet accepted the invitation request. You can reinvite a user by clicking Re-invite.
Requested | Invited users who haven't yet been approved by an admin. This admin invitation mode can only be enabled by SAP LeanIX Support.
Not invited | Users subscribed to fact sheets as contacts. To learn more about contacts, see [Contacts](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758f7bb7a4410148ebaeb6edf8d8e3f__contacts).
Archived | Users whose permission for the workspace is archived (deactivated). Archived users don't have access to the workspace.


